# importing necessary libraries
import pandas as pd
from pymongo.mongo_client import MongoClient
from typing import List, Dict
from pathlib import Path

# load csv file:
def load_csv(filepath:Path, delimiter:str):
    filepath = Path(filepath)
    return pd.read_csv(str(filepath), delimiter=delimiter)
    
# load excel sheet
def load_excelsheet(filepath:Path, sheet_name:str):
    filepath = Path(filepath)
    return pd.read_excel(str(filepath), sheet_name=sheet_name)

# load google sheet 
def load_gsheet(gsheet_id:str, sheet_name:str):
    base_url = 'https://docs.google.com/spreadsheets/d'
    sheet_csv = 'gviz/tq?tqx=out:csv&sheet='
    url = f'{base_url}/{gsheet_id}/{sheet_csv}{sheet_name}'
    return pd.read_csv(url)

# load mongodb data:
def load_mongodbdata(host:str, database:str, collection:str):
    client: MongoClient = MongoClient(host)
    db = client[database]
    col = db[collection]
    records = col.find()
    data: List[Dict] = list(records)
    df = pd.DataFrame(data)
    df.drop('_id', axis=1, inplace=True)
    return df



# importing necessary libraries:
from setuptools import setup, find_packages
from pathlib import Path
import warnings
warnings.filterwarnings('ignore')

# setup:
# basic info:
PKG_NAME = 'dbsconnector'
__version__ = '1.1'
AUTHOR_USER_NAME = 'yuvaneshkm'
AUTHOR_EMAIL = 'yuvaneshkm05@gmail.com'
REPO_NAME = 'dbsconnector'

def read_file(filepath):
    filepath = Path(filepath)
    with open(filepath, 'r', encoding='utf-8') as f:
        return f.read()

# setup:
setup(
    name = PKG_NAME,
    version = __version__,
    author = AUTHOR_USER_NAME,
    author_email = AUTHOR_EMAIL,
    description = 'Python package for connecting and importing data from different DataBases',
    long_description = read_file('README.md'),
    long_description_content_type = 'text/markdown',
    url = f'https://github.com/{AUTHOR_USER_NAME}/{REPO_NAME}',
    project_urls = {
        'Bug Trackers':f'https://github.com/{AUTHOR_USER_NAME}/{REPO_NAME}/issues'
    },
    package_dir = {"":'src'},
    packages = find_packages(where='src') 
)
